@@ -1,7 +1,7 @@
 #' Resolve Guide
 #'
 #' Resolves implicit usage of default key 'guide' to explicit usage.
-#' Generic, with method for data.frame.
+#' Generic, with method \code{\link{resolve.decorated}}.
 #' @param x object
 #' @param ... passed arguments
 #' @export
@@ -9,29 +9,31 @@
 #' @return see methods
 #' @family resolve
 #' @examples
-#' example(resolve.data.frame)
+#' example(resolve.decorated)
 resolve <- function(x, ...)UseMethod('resolve')
 
-#' Resolve Guide for Data Frame
+#' Resolve Guide for Decorated
 #'
 #' Resolves implicit usage of default key 'guide' to
-#' explicit usage for data.frame.
+#' explicit usage for decorated class.
 #' Simply calls \code{\link{explicit_guide}}
 #' followed by \code{\link{factorize_codelist}}.
 #' @param x object
-#' @param ... passed arguments
+#' @param ... passed to \code{\link{explicit_guide}} and \code{\link{factorize_codelist}}
 #' @export
-#' @return data.frame
+#' @return class 'resolved' (and inherited classes)
 #' @family resolve
 #' @family interface
 #' @examples
 #' library(magrittr)
 #' file <- system.file(package = 'yamlet', 'extdata','quinidine.csv')
 #' x <- decorate(file)
-#' x %>% resolve(default = 'unit') %>% as_yamlet
+#' x %>% resolve %>% decorations(Age, glyco)
+#' x %>% resolve(glyco) %>% decorations(Age, glyco)
 
-resolve.data.frame <- function(x, ...){
+resolve.decorated <- function(x, ...){
   x <- explicit_guide(x, ...)
   x <- factorize_codelist(x, ...)
+  class(x) <- union('resolved', class(x))
   x
 }
